@@ -1,6 +1,6 @@
 import sys
 import typing
-import bpy
+import bpy.types
 
 active_base: 'bpy.types.ObjectBase' = None
 
@@ -8,13 +8,14 @@ active_bone: 'bpy.types.EditBone' = None
 
 active_gpencil_brush: 'bpy.types.GPencilSculptBrush' = None
 
-active_gpencil_frame = None
+active_gpencil_frame: list = None
 
-active_gpencil_layer: 'bpy.types.GPencilLayer' = None
+active_gpencil_layer: typing.List['bpy.types.GPencilLayer'] = None
 
-active_gpencil_palette: 'bpy.types.GPencilPalette' = None
+active_gpencil_palette: typing.List['bpy.types.GPencilPalette'] = None
 
-active_gpencil_palettecolor: 'bpy.types.GPencilPaletteColor' = None
+active_gpencil_palettecolor: typing.List[
+    'bpy.types.GPencilPaletteColor'] = None
 
 active_node: 'bpy.types.Node' = None
 
@@ -56,15 +57,15 @@ edit_object: 'bpy.types.Object' = None
 
 edit_text: 'bpy.types.Text' = None
 
-editable_bases: 'bpy.types.ObjectBase' = None
+editable_bases: typing.List['bpy.types.ObjectBase'] = None
 
-editable_bones: 'bpy.types.EditBone' = None
+editable_bones: typing.List['bpy.types.EditBone'] = None
 
-editable_gpencil_layers: 'bpy.types.GPencilLayer' = None
+editable_gpencil_layers: typing.List['bpy.types.GPencilLayer'] = None
 
-editable_gpencil_strokes: 'bpy.types.GPencilStroke' = None
+editable_gpencil_strokes: typing.List['bpy.types.GPencilStroke'] = None
 
-editable_objects: 'bpy.types.Object' = None
+editable_objects: typing.List['bpy.types.Object'] = None
 
 fluid: 'bpy.types.FluidSimulationModifier' = None
 
@@ -88,7 +89,7 @@ mesh: 'bpy.types.Mesh' = None
 
 meta_ball: 'bpy.types.MetaBall' = None
 
-mode: int = None
+mode: typing.Union[str, int] = None
 
 object: 'bpy.types.Object' = None
 
@@ -112,31 +113,31 @@ screen: 'bpy.types.Screen' = None
 
 sculpt_object: 'bpy.types.Object' = None
 
-selectable_bases: 'bpy.types.ObjectBase' = None
+selectable_bases: typing.List['bpy.types.ObjectBase'] = None
 
-selectable_objects: 'bpy.types.Object' = None
+selectable_objects: typing.List['bpy.types.Object'] = None
 
-selected_bases: 'bpy.types.ObjectBase' = None
+selected_bases: typing.List['bpy.types.ObjectBase'] = None
 
-selected_bones: 'bpy.types.EditBone' = None
+selected_bones: typing.List['bpy.types.EditBone'] = None
 
-selected_editable_bases: 'bpy.types.ObjectBase' = None
+selected_editable_bases: typing.List['bpy.types.ObjectBase'] = None
 
-selected_editable_bones: 'bpy.types.EditBone' = None
+selected_editable_bones: typing.List['bpy.types.EditBone'] = None
 
-selected_editable_objects: 'bpy.types.Object' = None
+selected_editable_objects: typing.List['bpy.types.Object'] = None
 
-selected_editable_sequences: 'bpy.types.Sequence' = None
+selected_editable_sequences: typing.List['bpy.types.Sequence'] = None
 
-selected_nodes: 'bpy.types.Node' = None
+selected_nodes: typing.List['bpy.types.Node'] = None
 
-selected_objects: 'bpy.types.Object' = None
+selected_objects: typing.List['bpy.types.Object'] = None
 
-selected_pose_bones: 'bpy.types.PoseBone' = None
+selected_pose_bones: typing.List['bpy.types.PoseBone'] = None
 
-selected_sequences: 'bpy.types.Sequence' = None
+selected_sequences: typing.List['bpy.types.Sequence'] = None
 
-sequences: 'bpy.types.Sequence' = None
+sequences: typing.List['bpy.types.Sequence'] = None
 
 smoke: 'bpy.types.SmokeModifier' = None
 
@@ -160,15 +161,15 @@ user_preferences: 'bpy.types.UserPreferences' = None
 
 vertex_paint_object: 'bpy.types.Object' = None
 
-visible_bases: 'bpy.types.ObjectBase' = None
+visible_bases: typing.List['bpy.types.ObjectBase'] = None
 
-visible_bones: 'bpy.types.EditBone' = None
+visible_bones: typing.List['bpy.types.EditBone'] = None
 
-visible_gpencil_layers: 'bpy.types.GPencilLayer' = None
+visible_gpencil_layers: typing.List['bpy.types.GPencilLayer'] = None
 
-visible_objects: 'bpy.types.Object' = None
+visible_objects: typing.List['bpy.types.Object'] = None
 
-visible_pose_bones: 'bpy.types.PoseBone' = None
+visible_pose_bones: typing.List['bpy.types.PoseBone'] = None
 
 weight_paint_object: 'bpy.types.Object' = None
 
