@@ -34,7 +34,7 @@ def addon_expand(module: str = ""):
 
 
 def addon_install(overwrite: bool = True,
-                  target: typing.Union[int, str] = 'DEFAULT',
+                  target: typing.Union[str, int] = 'DEFAULT',
                   filepath: str = "",
                   filter_folder: bool = True,
                   filter_python: bool = True,
@@ -44,7 +44,7 @@ def addon_install(overwrite: bool = True,
     :param overwrite: Overwrite, Remove existing add-ons with the same ID
     :type overwrite: bool
     :param target: Target Path
-    :type target: typing.Union[int, str]
+    :type target: typing.Union[str, int]
     :param filepath: filepath
     :type filepath: str
     :param filter_folder: Filter folders
@@ -102,8 +102,8 @@ def alembic_export(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[int, str] = 'DEFAULT',
-                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[str, int] = 'DEFAULT',
+                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                    start: int = 1,
                    end: int = 1,
                    xsamples: int = 1,
@@ -121,7 +121,7 @@ def alembic_export(filepath: str = "",
                    face_sets: bool = False,
                    subdiv_schema: bool = False,
                    apply_subdiv: bool = False,
-                   compression_type: typing.Union[int, str] = 'OGAWA',
+                   compression_type: typing.Union[str, int] = 'OGAWA',
                    global_scale: float = 1.0):
     ''' Export current scene in an Alembic archive
 
@@ -158,9 +158,9 @@ def alembic_export(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param start: Start Frame, Start Frame
     :type start: int
     :param end: End Frame, End Frame
@@ -196,7 +196,7 @@ def alembic_export(filepath: str = "",
     :param apply_subdiv: Apply Subsurf, Export subdivision surfaces as meshes
     :type apply_subdiv: bool
     :param compression_type: Compression
-    :type compression_type: typing.Union[int, str]
+    :type compression_type: typing.Union[str, int]
     :param global_scale: Scale, Value by which to enlarge or shrink the objects with respect to the world's origin
     :type global_scale: float
     '''
@@ -220,8 +220,8 @@ def alembic_import(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[int, str] = 'DEFAULT',
-                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[str, int] = 'DEFAULT',
+                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                    scale: float = 1.0,
                    set_frame_range: bool = True,
                    validate_meshes: bool = False,
@@ -261,9 +261,9 @@ def alembic_import(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param scale: Scale, Value by which to enlarge or shrink the objects with respect to the world's origin
     :type scale: float
     :param set_frame_range: Set Frame Range, If checked, update scene's start and end frame to match those of the Alembic archive
@@ -316,8 +316,8 @@ def append(filepath: str = "",
            filter_folder: bool = True,
            filter_blenlib: bool = True,
            filemode: int = 1,
-           display_type: typing.Union[int, str] = 'DEFAULT',
-           sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+           display_type: typing.Union[str, int] = 'DEFAULT',
+           sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
            link: bool = False,
            autoselect: bool = True,
            active_layer: bool = True,
@@ -363,9 +363,9 @@ def append(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param link: Link, Link the objects or datablocks rather than appending
     :type link: bool
     :param autoselect: Select, Select new objects
@@ -427,11 +427,11 @@ def collada_export(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[int, str] = 'DEFAULT',
-                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[str, int] = 'DEFAULT',
+                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                    apply_modifiers: bool = False,
                    export_mesh_type: int = 0,
-                   export_mesh_type_selection: typing.Union[int, str] = 'view',
+                   export_mesh_type_selection: typing.Union[str, int] = 'view',
                    selected: bool = False,
                    include_children: bool = False,
                    include_armatures: bool = False,
@@ -447,7 +447,7 @@ def collada_export(filepath: str = "",
                    sort_by_name: bool = False,
                    export_transformation_type: int = 0,
                    export_transformation_type_selection: typing.
-                   Union[int, str] = 'matrix',
+                   Union[str, int] = 'matrix',
                    open_sim: bool = False):
     ''' Save a Collada file
 
@@ -484,15 +484,15 @@ def collada_export(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param apply_modifiers: Apply Modifiers, Apply modifiers to exported mesh (non destructive))
     :type apply_modifiers: bool
     :param export_mesh_type: Resolution, Modifier resolution for export
     :type export_mesh_type: int
     :param export_mesh_type_selection: Resolution, Modifier resolution for export * view View, Apply modifier's view settings. * render Render, Apply modifier's render settings.
-    :type export_mesh_type_selection: typing.Union[int, str]
+    :type export_mesh_type_selection: typing.Union[str, int]
     :param selected: Selection Only, Export only selected elements
     :type selected: bool
     :param include_children: Include Children, Export all children of selected objects (even if not selected)
@@ -522,7 +522,7 @@ def collada_export(filepath: str = "",
     :param export_transformation_type: Transform, Transformation type for translation, scale and rotation
     :type export_transformation_type: int
     :param export_transformation_type_selection: Transform, Transformation type for translation, scale and rotation * matrix Matrix, Use <matrix> to specify transformations. * transrotloc TransRotLoc, Use <translate>, <rotate>, <scale> to specify transformations. * both Both, Use <matrix> AND <translate>, <rotate>, <scale> to specify transformations.
-    :type export_transformation_type_selection: typing.Union[int, str]
+    :type export_transformation_type_selection: typing.Union[str, int]
     :param open_sim: Export to SL/OpenSim, Compatibility mode for SL, OpenSim and other compatible online worlds
     :type open_sim: bool
     '''
@@ -545,8 +545,8 @@ def collada_import(filepath: str = "",
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[int, str] = 'DEFAULT',
-                   sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                   display_type: typing.Union[str, int] = 'DEFAULT',
+                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                    import_units: bool = False,
                    fix_orientation: bool = False,
                    find_chains: bool = False,
@@ -585,9 +585,9 @@ def collada_import(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param import_units: Import Units, If disabled match import to Blender's current Unit settings, otherwise use the settings from the Imported scene
     :type import_units: bool
     :param fix_orientation: Fix Leaf Bones, Fix Orientation of Leaf Bones (Collada does only support Joints)
@@ -605,7 +605,7 @@ def collada_import(filepath: str = "",
 
 def context_collection_boolean_set(data_path_iter: str = "",
                                    data_path_item: str = "",
-                                   type: typing.Union[int, str] = 'TOGGLE'):
+                                   type: typing.Union[str, int] = 'TOGGLE'):
     ''' Set boolean values for a collection of items
 
     :param data_path_iter: data_path_iter, The data path relative to the context, must point to an iterable
@@ -613,7 +613,7 @@ def context_collection_boolean_set(data_path_iter: str = "",
     :param data_path_item: data_path_item, The data path from each iterable to the value (int or float)
     :type data_path_item: str
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -1068,8 +1068,8 @@ def lib_reload(library: str = "",
                filter_blenlib: bool = False,
                filemode: int = 8,
                relative_path: bool = True,
-               display_type: typing.Union[int, str] = 'DEFAULT',
-               sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+               display_type: typing.Union[str, int] = 'DEFAULT',
+               sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Reload the given library
 
     :param library: Library, Library to reload
@@ -1111,9 +1111,9 @@ def lib_reload(library: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -1143,8 +1143,8 @@ def lib_relocate(
         filter_blenlib: bool = False,
         filemode: int = 8,
         relative_path: bool = True,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Relocate the given library to one or several others
 
     :param library: Library, Library to relocate
@@ -1188,9 +1188,9 @@ def lib_relocate(
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -1218,8 +1218,8 @@ def link(filepath: str = "",
          filter_blenlib: bool = True,
          filemode: int = 1,
          relative_path: bool = True,
-         display_type: typing.Union[int, str] = 'DEFAULT',
-         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+         display_type: typing.Union[str, int] = 'DEFAULT',
+         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
          link: bool = True,
          autoselect: bool = True,
          active_layer: bool = True,
@@ -1265,9 +1265,9 @@ def link(filepath: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param link: Link, Link the objects or datablocks rather than appending
     :type link: bool
     :param autoselect: Select, Select new objects
@@ -1304,8 +1304,8 @@ def open_mainfile(filepath: str = "",
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
-                  display_type: typing.Union[int, str] = 'DEFAULT',
-                  sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                  display_type: typing.Union[str, int] = 'DEFAULT',
+                  sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                   load_ui: bool = True,
                   use_scripts: bool = True):
     ''' Open a Blender file
@@ -1341,9 +1341,9 @@ def open_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param load_ui: Load UI, Load user interface setup in the .blend file
     :type load_ui: bool
     :param use_scripts: Trusted Source, Allow .blend file to execute scripts automatically, default available from system preferences
@@ -1489,14 +1489,14 @@ def previews_batch_generate(
     pass
 
 
-def previews_clear(id_type: typing.Union[typing.Set[int], typing.Set[str]] = {
+def previews_clear(id_type: typing.Union[typing.Set[str], typing.Set[int]] = {
         'GROUP', 'IMAGE', 'LAMP', 'MATERIAL', 'OBJECT', 'SCENE', 'TEXTURE',
         'WORLD'
 }):
     ''' Clear datablock previews (only for some types like objects, materials, textures, etc.)
 
     :param id_type: DataBlock Type, Which datablock previews to clear
-    :type id_type: typing.Union[typing.Set[int], typing.Set[str]]
+    :type id_type: typing.Union[typing.Set[str], typing.Set[int]]
     '''
 
     pass
@@ -1667,8 +1667,8 @@ def recover_auto_save(filepath: str = "",
                       filter_folder: bool = False,
                       filter_blenlib: bool = False,
                       filemode: int = 8,
-                      display_type: typing.Union[int, str] = 'LIST_LONG',
-                      sort_method: typing.Union[int, str] = 'FILE_SORT_TIME'):
+                      display_type: typing.Union[str, int] = 'LIST_LONG',
+                      sort_method: typing.Union[str, int] = 'FILE_SORT_TIME'):
     ''' Open an automatically saved file to recover it
 
     :param filepath: File Path, Path to file
@@ -1702,9 +1702,9 @@ def recover_auto_save(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -1718,13 +1718,13 @@ def recover_last_session():
     pass
 
 
-def redraw_timer(type: typing.Union[int, str] = 'DRAW',
+def redraw_timer(type: typing.Union[str, int] = 'DRAW',
                  iterations: int = 10,
                  time_limit: float = 0.0):
     ''' Simple redraw timer to test the speed of updating the interface
 
     :param type: Type * DRAW Draw Region, Draw Region. * DRAW_SWAP Draw Region + Swap, Draw Region and Swap. * DRAW_WIN Draw Window, Draw Window. * DRAW_WIN_SWAP Draw Window + Swap, Draw Window and Swap. * ANIM_STEP Anim Step, Animation Steps. * ANIM_PLAY Anim Play, Animation Playback. * UNDO Undo/Redo, Undo/Redo.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param iterations: Iterations, Number of times to redraw
     :type iterations: int
     :param time_limit: Time Limit, Seconds to run the test for (override iterations)
@@ -1760,8 +1760,8 @@ def save_as_mainfile(filepath: str = "",
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
-                     display_type: typing.Union[int, str] = 'DEFAULT',
-                     sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                     display_type: typing.Union[str, int] = 'DEFAULT',
+                     sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                      compress: bool = False,
                      relative_remap: bool = True,
                      copy: bool = False,
@@ -1801,9 +1801,9 @@ def save_as_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param compress: Compress, Write compressed .blend file
     :type compress: bool
     :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory
@@ -1841,8 +1841,8 @@ def save_mainfile(filepath: str = "",
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
-                  display_type: typing.Union[int, str] = 'DEFAULT',
-                  sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+                  display_type: typing.Union[str, int] = 'DEFAULT',
+                  sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                   compress: bool = False,
                   relative_remap: bool = False):
     ''' Save the current Blender file
@@ -1880,9 +1880,9 @@ def save_mainfile(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     :param compress: Compress, Write compressed .blend file
     :type compress: bool
     :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory
@@ -1908,19 +1908,19 @@ def search_menu():
     pass
 
 
-def set_stereo_3d(display_mode: typing.Union[int, str] = 'ANAGLYPH',
-                  anaglyph_type: typing.Union[int, str] = 'RED_CYAN',
-                  interlace_type: typing.Union[int, str] = 'ROW_INTERLEAVED',
+def set_stereo_3d(display_mode: typing.Union[str, int] = 'ANAGLYPH',
+                  anaglyph_type: typing.Union[str, int] = 'RED_CYAN',
+                  interlace_type: typing.Union[str, int] = 'ROW_INTERLEAVED',
                   use_interlace_swap: bool = False,
                   use_sidebyside_crosseyed: bool = False):
     ''' Toggle 3D stereo support for current window (or change the display mode)
 
     :param display_mode: Display Mode * ANAGLYPH Anaglyph, Render views for left and right eyes as two differently filtered colors in a single image (anaglyph glasses are required). * INTERLACE Interlace, Render views for left and right eyes interlaced in a single image (3D-ready monitor is required). * TIMESEQUENTIAL Time Sequential, Render alternate eyes (also known as page flip, quad buffer support in the graphic card is required). * SIDEBYSIDE Side-by-Side, Render views for left and right eyes side-by-side. * TOPBOTTOM Top-Bottom, Render views for left and right eyes one above another.
-    :type display_mode: typing.Union[int, str]
+    :type display_mode: typing.Union[str, int]
     :param anaglyph_type: Anaglyph Type
-    :type anaglyph_type: typing.Union[int, str]
+    :type anaglyph_type: typing.Union[str, int]
     :param interlace_type: Interlace Type
-    :type interlace_type: typing.Union[int, str]
+    :type interlace_type: typing.Union[str, int]
     :param use_interlace_swap: Swap Left/Right, Swap left and right stereo channels
     :type use_interlace_swap: bool
     :param use_sidebyside_crosseyed: Cross-Eyed, Right eye should see left image and vice-versa
