@@ -1,5 +1,6 @@
 import sys
 import typing
+import bpy.types
 
 
 def BoolProperty(name: str = "",
@@ -9,7 +10,7 @@ def BoolProperty(name: str = "",
                  subtype: str = 'NONE',
                  update=None,
                  get=None,
-                 set=None):
+                 set=None) -> 'bpy.types.BoolProperty':
     ''' Returns a new boolean property definition.
 
     :param name: Name used in the user interface.
@@ -36,7 +37,7 @@ def BoolVectorProperty(name: str = "",
                        size: int = 3,
                        update=None,
                        get=None,
-                       set=None):
+                       set=None) -> typing.List['bpy.types.BoolProperty']:
     ''' Returns a new vector boolean property definition.
 
     :param name: Name used in the user interface.
@@ -59,10 +60,11 @@ def BoolVectorProperty(name: str = "",
     pass
 
 
-def CollectionProperty(type=None,
-                       name: str = "",
-                       description: str = "",
-                       options: set = {'ANIMATABLE'}):
+def CollectionProperty(
+        type=None,
+        name: str = "",
+        description: str = "",
+        options: set = {'ANIMATABLE'}) -> 'bpy.types.CollectionProperty':
     ''' Returns a new collection property definition.
 
     :param type: bpy.types.PropertyGroup .
@@ -84,7 +86,7 @@ def EnumProperty(items: typing.List[str],
                  options: set = {'ANIMATABLE'},
                  update=None,
                  get=None,
-                 set=None):
+                 set=None) -> 'bpy.types.EnumProperty':
     ''' Returns a new enumerator property definition.
 
     :param items: [(identifier, name, description, icon, number), ...] . The first three elements of the tuples are mandatory. :identifier: The identifier is used for Python access. :name: Name for the interace. :description: Used for documentation and tooltips. :icon: An icon string identifier or integer icon value (e.g. returned by bpy.types.UILayout.icon ) :number: Unique value used as the identifier for this item (stored in file data). Use when the identifier may need to change. When an item only contains 4 items they define (identifier, name, description, number) . For dynamic values a callback can be passed which returns a list in the same format as the static list. This function must take 2 arguments (self, context) , **context may be None**. .. warning:: There is a known bug with using a callback, Python must keep a reference to the strings returned or Blender will crash.
@@ -119,7 +121,7 @@ def FloatProperty(name: str = "",
                   unit: str = 'NONE',
                   update=None,
                   get=None,
-                  set=None):
+                  set=None) -> 'bpy.types.FloatProperty':
     ''' Returns a new float property definition.
 
     :param name: Name used in the user interface.
@@ -167,7 +169,7 @@ def FloatVectorProperty(name: str = "",
                         size: int = 3,
                         update=None,
                         get=None,
-                        set=None):
+                        set=None) -> typing.List['bpy.types.FloatProperty']:
     ''' Returns a new vector float property definition.
 
     :param name: Name used in the user interface.
@@ -216,7 +218,7 @@ def IntProperty(name: str = "",
                 subtype: str = 'NONE',
                 update=None,
                 get=None,
-                set=None):
+                set=None) -> 'bpy.types.IntProperty':
     ''' Returns a new int property definition.
 
     :param name: Name used in the user interface.
@@ -258,7 +260,7 @@ def IntVectorProperty(name: str = "",
                       size: int = 3,
                       update=None,
                       get=None,
-                      set=None):
+                      set=None) -> typing.List['bpy.types.IntProperty']:
     ''' Returns a new vector int property definition.
 
     :param name: Name used in the user interface.
@@ -295,7 +297,7 @@ def PointerProperty(type=None,
                     name: str = "",
                     description: str = "",
                     options: set = {'ANIMATABLE'},
-                    update=None):
+                    update=None) -> 'bpy.types.PointerProperty':
     ''' Returns a new pointer property definition.
 
     :param type: bpy.types.PropertyGroup .
@@ -330,7 +332,7 @@ def StringProperty(name: str = "",
                    subtype: str = 'NONE',
                    update=None,
                    get=None,
-                   set=None):
+                   set=None) -> 'bpy.types.StringProperty':
     ''' Returns a new string property definition.
 
     :param name: Name used in the user interface.
