@@ -2,8 +2,8 @@ import sys
 import typing
 import bpy.types
 import mathutils
-import bpy.context
 import bpy
+import bpy.context
 
 
 class AddObjectHelper:
@@ -46,7 +46,7 @@ def object_add_grid_scale_apply_operator(operator, context):
 
 
 def object_data_add(context: 'bpy.types.Context',
-                    obdata: typing.Union['bpy.context.object', 'bpy.data'],
+                    obdata: typing.Union['bpy.data', 'bpy.context.object'],
                     operator: 'bpy.types.Operator' = None,
                     use_active_layer=True,
                     name: str = None) -> 'bpy.types.ObjectBase':
@@ -55,7 +55,7 @@ def object_data_add(context: 'bpy.types.Context',
     :param context: The context to use.
     :type context: 'bpy.types.Context'
     :param obdata: the data used for the new object.
-    :type obdata: typing.Union['bpy.context.object', 'bpy.data']
+    :type obdata: typing.Union['bpy.data', 'bpy.context.object']
     :param operator: The operator, checked for location and rotation properties.
     :type operator: 'bpy.types.Operator'
     :param name: Optional name
