@@ -23,3 +23,18 @@ class GPUOffscreen:
 
     :type: int
     '''
+
+
+def new(width: int, height: int, samples: int = 0):
+    ''' Return a GPUOffScreen.
+
+    :param width: Horizontal dimension of the buffer.
+    :type width: int
+    :param height: Vertical dimension of the buffer.
+    :type height: int
+    :param samples: OpenGL samples to use for MSAA or zero to disable.
+    :type samples: int
+    :return: Newly created off-screen buffer.
+    '''
+
+    pass
